#[non_exhaustive]pub enum SiwxError {
Show 15 variants
DomainMismatch,
UriMismatch,
IssuedAt,
IssuedAtTooOld,
IssuedAtInFuture,
ExpirationTime,
Expired,
NotBefore,
NotYetValid,
Nonce,
Signature,
ChainId,
UnsupportedChain,
MalformedSignature,
VerifierError,
}Available on crate features
server and siwx only.Expand description
Spec invalid_siwx_* failure codes.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DomainMismatch
domain does not match the configured public origin host.
UriMismatch
uri origin does not match the configured public origin.
IssuedAt
issuedAt is not a valid timestamp.
IssuedAtTooOld
issuedAt exceeds the maximum age.
IssuedAtInFuture
issuedAt is in the future.
ExpirationTime
expirationTime is not a valid timestamp.
Expired
expirationTime is in the past.
NotBefore
notBefore is not a valid timestamp.
NotYetValid
notBefore is in the future.
Nonce
Nonce failed uniqueness or format validation.
Signature
Cryptographic signature verification failed.
ChainId
chainId is not a valid CAIP-2 identifier.
UnsupportedChain
chainId namespace is not supported.
MalformedSignature
Signature or address encoding is invalid.
VerifierError
Verifier threw (for example RPC unavailable during EIP-1271).
Implementations